// Arduino IDE Sketch for Lian Li ATX Strimer Plus
// created by FeuerSturm
#include <CorsairLightingProtocol.h>
#include <FastLED.h>

#define LEDS_PER_DATA 20

// If you want to use other pins than 2,3,4,5,6,7 for the data lines instead, change them here:
#define STRIMER_DATA1 2
#define STRIMER_DATA2 3
#define STRIMER_DATA3 4
#define STRIMER_DATA4 5
#define STRIMER_DATA5 6
#define STRIMER_DATA6 7
// DO NOT EDIT BELOW THIS LINE UNLESS YOU KNOW WHAT YOU ARE DOING!

CRGB ledsChannel1[60];
CRGB ledsChannel2[60];

const char mySerialNumber[] PROGMEM = "2021A4B5C6D7";

CorsairLightingFirmwareStorageEEPROM firmwareStorage;
CorsairLightingFirmware firmware(CORSAIR_LIGHTING_NODE_PRO, &firmwareStorage);
FastLEDControllerStorageEEPROM storage;
FastLEDController ledController(&storage);
CorsairLightingProtocolController cLP(&ledController, &firmware);
CorsairLightingProtocolHID cHID(&cLP, mySerialNumber);

void setup()
{
	DeviceID deviceId = { 0xA4, 0xB5, 0xC6, 0xD7 };
	firmware.setDeviceID(deviceId);
	CLP::disableBuildInLEDs();
	FastLED.addLeds<WS2812B, STRIMER_DATA1, GRB>(ledsChannel1, LEDS_PER_DATA * 0, LEDS_PER_DATA);
	FastLED.addLeds<WS2812B, STRIMER_DATA2, GRB>(ledsChannel1, LEDS_PER_DATA * 1, LEDS_PER_DATA);
	FastLED.addLeds<WS2812B, STRIMER_DATA3, GRB>(ledsChannel1, LEDS_PER_DATA * 2, LEDS_PER_DATA);
 
	FastLED.addLeds<WS2812B, STRIMER_DATA4, GRB>(ledsChannel2, LEDS_PER_DATA * 0, LEDS_PER_DATA);
	FastLED.addLeds<WS2812B, STRIMER_DATA5, GRB>(ledsChannel2, LEDS_PER_DATA * 1, LEDS_PER_DATA);
	FastLED.addLeds<WS2812B, STRIMER_DATA6, GRB>(ledsChannel2, LEDS_PER_DATA * 2, LEDS_PER_DATA);
  
	ledController.addLEDs(0, ledsChannel1, 60);
	ledController.addLEDs(1, ledsChannel2, 60);
}

void loop()
{
	cHID.update();
  
	if (ledController.updateLEDs())
	{
		FastLED.show();
	}
}
